aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/ArmorSlot.h
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
commit7074f35e4ba831e358117842b99ee35b87f85ae5 (patch)
tree7d440d23473196af3056bf2ff4c59d9e740a06f5 /Minecraft.World/ArmorSlot.h
parentd63f79325f85e014361eb8cf1e41eaebedb1ae71 (diff)
shared_ptr -> std::shared_ptr
This is one of the first commits in a plan to remove all `using namespace std;` lines in the entire codebase as it is considered anti-pattern today.
Diffstat (limited to 'Minecraft.World/ArmorSlot.h')
-rw-r--r--Minecraft.World/ArmorSlot.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Minecraft.World/ArmorSlot.h b/Minecraft.World/ArmorSlot.h
index a9797be2..2bf02067 100644
--- a/Minecraft.World/ArmorSlot.h
+++ b/Minecraft.World/ArmorSlot.h
@@ -13,12 +13,12 @@ private:
const int slotNum;
public:
- ArmorSlot(int slotNum, shared_ptr<Container> container, int id, int x, int y);
+ ArmorSlot(int slotNum, std::shared_ptr<Container> container, int id, int x, int y);
virtual ~ArmorSlot() {}
virtual int getMaxStackSize();
- virtual bool mayPlace(shared_ptr<ItemInstance> item);
+ virtual bool mayPlace(std::shared_ptr<ItemInstance> item);
Icon *getNoItemIcon();
//virtual bool mayCombine(shared_ptr<ItemInstance> item); // 4J Added
//virtual shared_ptr<ItemInstance> combine(shared_ptr<ItemInstance> item); // 4J Added
}; \ No newline at end of file
@@ -13,12 +13,12 @@ private:
Icon *getNoItemIcon();
- //virtual bool mayCombine(shared_ptr<ItemInstance> item); // 4J Added
- //virtual shared_ptr<ItemInstance> combine(shared_ptr<ItemInstance> item); // 4J Added
+ //virtual bool mayCombine(std::shared_ptr<ItemInstance> item); // 4J Added
+ //virtual std::shared_ptr<ItemInstance> combine(std::shared_ptr<ItemInstance> item); // 4J Added
}; \ No newline at end of file